@@ -1,6 +1,6 @@
 from .__core__ import PyotCore, PyotStatic
-from ...stores.cdragon import CDragon, CDragonTransformers
-from ...core.exceptions import NotFound
+from pyot.utils.cdragon import cdragon_url, cdragon_sanitize
+from pyot.core.exceptions import NotFound
 from typing import List, Iterator
 
 
@@ -44,16 +44,15 @@ class Item(PyotCore):
                 return item
         raise NotFound
 
-    async def _refactor(self):
+    def _refactor(self):
         if self.locale.lower() == "en_us":
-            self.Meta.server = "default"
-        load = getattr(self.Meta, "load")
+            self.meta.server = "default"
+        load = getattr(self.meta, "load")
         load.pop("id")
 
-    async def _transform(self, data):
-        tr = CDragonTransformers(self.locale)
-        data["iconPath"] = tr.url_assets(data["iconPath"])
-        data["cleanedDescription"] = tr.sanitize(data["description"])
+    def _transform(self, data):
+        data["iconPath"] = cdragon_url(data["iconPath"])
+        data["cleanedDescription"] = cdragon_sanitize(data["description"])
         if data["requiredChampion"] == "":
             data["requiredChampion"] = None
         if data["requiredBuffCurrencyName"] == "":
@@ -96,16 +95,15 @@ class Items(PyotCore):
     def __iter__(self) -> Iterator[Item]:
         return iter(self.items)
 
-    async def _refactor(self):
+    def _refactor(self):
         if self.locale.lower() == "en_us":
-            self.Meta.server = "default"
+            self.meta.server = "default"
 
-    async def _transform(self, data_):
-        tr = CDragonTransformers(self.locale)
+    def _transform(self, data_):
         items = []
         for data in data_:
-            data["iconPath"] = tr.url_assets(data["iconPath"])
-            data["cleanedDescription"] = tr.sanitize(data["description"])
+            data["iconPath"] = cdragon_url(data["iconPath"])
+            data["cleanedDescription"] = cdragon_sanitize(data["description"])
             if data["requiredChampion"] == "":
                 data["requiredChampion"] = None
             if data["requiredBuffCurrencyName"] == "":
