@@ -1,6 +1,6 @@
 from .__core__ import PyotCore
-from ...stores.cdragon import CDragon, CDragonTransformers
-from ...core.exceptions import NotFound
+from pyot.utils.cdragon import tft_item_sanitize, tft_url
+from pyot.core.exceptions import NotFound
 from typing import List, Iterator, Mapping
 
 
@@ -30,16 +30,15 @@ class Item(PyotCore):
                 return item
         raise NotFound
 
-    async def _refactor(self):
+    def _refactor(self):
         if self.locale.lower() == "default":
-            self.Meta.server = "en_us"
-        load = getattr(self.Meta, "load")
+            self.meta.server = "en_us"
+        load = getattr(self.meta, "load")
         load.pop("id")
 
-    async def _transform(self, data):
-        tr = CDragonTransformers(self.locale)
-        data["iconPath"] = tr.tft_url_assets(data.pop("icon"))
-        data["cleanedDescription"] = tr.tft_item_sanitize(data["desc"], data["effects"])
+    def _transform(self, data):
+        data["iconPath"] = tft_url(data.pop("icon"))
+        data["cleanedDescription"] = tft_item_sanitize(data["desc"], data["effects"])
         return data
 
     @property
@@ -62,18 +61,17 @@ class Items(PyotCore):
     def __iter__(self) -> Iterator[Item]:
         return iter(self.items)
 
-    async def _refactor(self):
+    def _refactor(self):
         if self.locale.lower() == "default":
-            self.Meta.server = "en_us"
+            self.meta.server = "en_us"
 
     def filter(self, data):
         return data["items"]
 
-    async def _transform(self, data_):
-        tr = CDragonTransformers(self.locale)
+    def _transform(self, data_):
         items = []
         for data in data_:
-            data["iconPath"] = tr.tft_url_assets(data.pop("icon"))
-            data["cleanedDescription"] = tr.tft_item_sanitize(data["desc"], data["effects"])
+            data["iconPath"] = tft_url(data.pop("icon"))
+            data["cleanedDescription"] = tft_item_sanitize(data["desc"], data["effects"])
             items.append({"data": data})
         return {"items": items}
