@@ -4,5 +4,7 @@ except ImportError:
     pass
 from .riotapi import RiotAPI
 from .omnistone import Omnistone
+from .rediscache import RedisCache
+from .diskcache import DiskCache
 from .merakicdn import MerakiCDN
-from .cdragon import CDragon
\ No newline at end of file
+from .cdragon import CDragon
